==> smart-testauto-framework-1.0.0-sources.jar: org/uitnet/testing/smartfwk/ui/core/objects/datetime/TimeItemValidator.java <==
/*
 * SmartTestAutoFramework
 * Copyright 2021 and beyond
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 */
package org.uitnet.testing.smartfwk.ui.core.objects.datetime;

import org.sikuli.script.Region;
import org.uitnet.testing.smartfwk.ui.core.config.webbrowser.WebBrowser;
import org.uitnet.testing.smartfwk.ui.core.objects.UIObjectValidator;
import org.uitnet.testing.smartfwk.ui.core.objects.validator.mechanisms.TextValidationMechanism;

/**
 * 
 * @author Madhav Krishna
 *
 */
public abstract class TimeItemValidator extends UIObjectValidator {
	private TimeItem timeItem;

	public TimeItemValidator(WebBrowser browser, TimeItem uiObject, Region region) {
		super(browser, uiObject, region);
		this.timeItem = uiObject;
	}

	@Override
	public TimeItem getUIObject() {
		return this.timeItem;
	}

	public abstract void validateDisabled(int numRetries);

	public abstract void validateEnabled(int numRetries);

	public abstract void typeTime(String time, int numRetries);

	public abstract void validateTime(String time, TextValidationMechanism validationMechanism, int numRetries);
}

==> smart-testauto-framework-1.0.3-sources.jar: org/uitnet/testing/smartfwk/ui/core/objects/datetime/TimeItemValidator.java <==
/*
 * SmartTestAutoFramework
 * Copyright 2021 and beyond
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 */
package org.uitnet.testing.smartfwk.ui.core.objects.datetime;

import org.sikuli.script.Region;
import org.uitnet.testing.smartfwk.ui.core.config.webbrowser.WebBrowser;
import org.uitnet.testing.smartfwk.ui.core.objects.UIObjectValidator;
import org.uitnet.testing.smartfwk.ui.core.objects.validator.mechanisms.TextMatchMechanism;

/**
 * 
 * @author Madhav Krishna
 *
 */
public abstract class TimeItemValidator extends UIObjectValidator {
	private TimeItem timeItem;

	public TimeItemValidator(WebBrowser browser, TimeItem uiObject, Region region) {
		super(browser, uiObject, region);
		this.timeItem = uiObject;
	}

	@Override
	public TimeItem getUIObject() {
		return this.timeItem;
	}

	public abstract void validateDisabled(int numRetries);

	public abstract void validateEnabled(int numRetries);

	public abstract void typeTime(String time, int numRetries);

	public abstract void validateTime(String time, TextMatchMechanism validationMechanism, int numRetries);
}
